@@ -744,7 +744,22 @@ void initialize(int argc, char **argv,
 	SizeHints.flags = USSize | USPosition;
 	SizeHints.x = 0;
 	SizeHints.y = 0;
-	XWMGeometry(mainDisplay, screen, mainGeometry, NULL, 1,
+	SizeHints.min_width =
+	    SizeHints.max_width =
+	    SizeHints.width = state.total_size.x;
+	SizeHints.min_height =
+	    SizeHints.max_height =
+	    SizeHints.height = state.total_size.y;
+	SizeHints.flags |= PMinSize | PMaxSize;
+	/*
+	 * The forth parameter is the window border width.
+	 * Set to 0 it makes astime look really queer in
+	 * AS when using -0-0 geometry. I have no idea why.
+	 * When the border is 1, everything is fine, but
+	 * the window is off by 1, of course.
+	 * It is probably a bug in AS.
+	 */
+	XWMGeometry(mainDisplay, screen, mainGeometry, NULL, 0,
 		    &SizeHints, &SizeHints.x, &SizeHints.y,
 		    &SizeHints.width, &SizeHints.height, &gravity);
 #ifdef DEBUG
@@ -753,24 +768,13 @@ void initialize(int argc, char **argv,
 	       state.total_size.x, state.total_size.y,
 	       SizeHints.x, SizeHints.y);
 #endif
-	SizeHints.min_width =
-	    SizeHints.max_width =
-	    SizeHints.width = state.total_size.x;
-	SizeHints.min_height =
-	    SizeHints.max_height =
-	    SizeHints.height = state.total_size.y;
-	SizeHints.flags |= PMinSize | PMaxSize;
 
 	/* Correct the offsets if the X/Y are negative */
 	SizeHints.win_gravity = NorthWestGravity;
 	if (x_negative) {
-		if ( ! x_size_forced )
-			SizeHints.x -= state.total_size.x;
 		SizeHints.win_gravity = NorthEastGravity;
 	}
 	if (y_negative) {
-		if ( ! y_size_forced )
-			SizeHints.y -= state.total_size.y;
 		if (x_negative)
 			SizeHints.win_gravity = SouthEastGravity;
 		else
